# OPS08-BP06: Alert when workload outcomes are at risk

## Description

Alerting khi có anomalies.

## Implementation Guidance

- SLO-based alerting
- Multi-window burn rate alerts
- Alert routing and escalation
- Alert fatigue prevention
- Actionable alert messages

## Risk Level

High - Missing alerts cause undetected outages.
